From: Stefan Kisdaroczi <kisda@domain.hid>
To: xenomai@xenomai.org
Subject: [Xenomai-core] [PATCH] rt_heap reminder
Date: Mon, 30 Jan 2006 23:11:33 +0100 [thread overview]
Message-ID: <200601302311.48645.kisda@domain.hid> (raw)
[-- Attachment #1.1: Type: text/plain, Size: 770 bytes --]
Hi all,
as a reminder (userspace, native skin, shared heap) [1]:
API documentation: "If the heap is shared, this value can be either zero, or
the same value given to rt_heap_create()."
This is not true. As the heapsize gets altered in rt_heap_create for page size
alignment, the following call to rt_heap_alloc with the same value will fail.
Ex:
rt_heap_create( ..., ..., 10000, ... )
rt_heap_alloc( ..., 10000, ..., .... ) -> This call fails
I suggest only accepting zero as a valid size for shared heaps.
about attached patch:
1) not tested
2) there are possible better names than H_ALL
3) the comments could be in a better english
4) i hope you get the idea
thx
kisda
[1] https://mail.gna.org/public/xenomai-core/2006-01/msg00177.html
[-- Attachment #1.2: rt_heap.patch --]
[-- Type: text/x-diff, Size: 2136 bytes --]
Index: include/native/heap.h
===================================================================
--- include/native/heap.h (Revision 465)
+++ include/native/heap.h (Arbeitskopie)
@@ -32,6 +32,9 @@
#define H_DMA 0x100 /* Use memory suitable for DMA. */
#define H_SHARED 0x200 /* Use mappable shared memory. */
+/* Operation flags. */
+#define H_ALL 0x0 /* Entire heap space. */
+
typedef struct rt_heap_info {
int nwaiters; /* !< Number of pending tasks. */
Index: ksrc/skins/native/heap.c
===================================================================
--- ksrc/skins/native/heap.c (Revision 465)
+++ ksrc/skins/native/heap.c (Arbeitskopie)
@@ -410,10 +410,9 @@
* from.
*
* @param size The requested size in bytes of the block. If the heap
* is shared, this value can be either zero, or the same value given
* to rt_heap_create(). In any case, the same block covering the
* entire heap space will always be returned to all callers of this
* service.
*
* @param timeout The number of clock ticks to wait for a block of
* sufficient size to be available from a local heap (see
@@ -432,8 +431,7 @@
* @return 0 is returned upon success. Otherwise:
*
* - -EINVAL is returned if @a heap is not a heap descriptor, or @a
- * heap is shared (i.e. H_SHARED mode) and @a size is non-zero but
- * does not match the actual heap size passed to rt_heap_create().
+ * heap is shared (i.e. H_SHARED mode) and @a size is not H_ALL.
*
* - -EIDRM is returned if @a heap is a deleted heap descriptor.
*
@@ -503,12 +501,7 @@
if (!block)
{
- /* It's ok to pass zero for size here, since the requested
- size is implicitely the whole heap space; but if
- non-zero is given, it must match the actual heap
- size. */
-
- if (size > 0 && size != xnheap_size(&heap->heap_base))
+ if (size != H_ALL)
{
err = -EINVAL;
goto unlock_and_exit;
[-- Attachment #2: Type: application/pgp-signature, Size: 189 bytes --]
next reply other threads:[~2006-01-30 22:11 UTC|newest]
Thread overview: 2+ messages / expand[flat|nested] mbox.gz Atom feed top
2006-01-30 22:11 Stefan Kisdaroczi [this message]
2006-01-31 14:22 ` [Xenomai-core] [PATCH] rt_heap reminder Philippe Gerum
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=200601302311.48645.kisda@domain.hid \
--to=kisda@domain.hid \
--cc=xenomai@xenomai.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -410,10 +410,9 @@
*
* @param size The requested size in bytes of the block. If the heap
- * is shared, this value can be either zero, or the same value given
- * to rt_heap_create(). In any case, the same block covering the
- * entire heap space will always be returned to all callers of this
- * service.
+ * is shared, H_ALL should be passed, as always the same block
+ * covering the entire heap space will be returned to all callers of
+ * this service.
*
* @param timeout The number of clock ticks to wait for a block of
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.